@@ -15,6 +15,7 @@ import (
 	"github.com/helmfile/helmfile/pkg/exectest"
 	ffs "github.com/helmfile/helmfile/pkg/filesystem"
 	"github.com/helmfile/helmfile/pkg/helmexec"
+	"github.com/helmfile/helmfile/pkg/runtime"
 	"github.com/helmfile/helmfile/pkg/testhelper"
 )
 
@@ -44,6 +45,7 @@ func TestTemplate(t *testing.T) {
 			DiffMutex:            &sync.Mutex{},
 			ChartsMutex:          &sync.Mutex{},
 			ReleasesMutex:        &sync.Mutex{},
+			Helm3:                true,
 		}
 
 		bs := runWithLogCapture(t, "debug", func(t *testing.T, logger *zap.SugaredLogger) {
@@ -235,7 +237,7 @@ releases:
 			},
 			selectors: []string{"name=test2"},
 			templated: []exectest.Release{
-				{Name: "test2", Flags: []string(nil)},
+				{Name: "test2", Flags: []string{}},
 			},
 		})
 	})
@@ -248,8 +250,8 @@ releases:
 			},
 			selectors: []string{"name=test3"},
 			templated: []exectest.Release{
-				{Name: "test2", Flags: []string(nil)},
-				{Name: "test3", Flags: []string(nil)},
+				{Name: "test2", Flags: []string{}},
+				{Name: "test3", Flags: []string{}},
 			},
 		})
 	})
@@ -263,8 +265,8 @@ releases:
 			},
 			selectors: []string{"name=test3"},
 			templated: []exectest.Release{
-				{Name: "test2", Flags: []string(nil)},
-				{Name: "test3", Flags: []string(nil)},
+				{Name: "test2", Flags: []string{}},
+				{Name: "test3", Flags: []string{}},
 			},
 		})
 	})
@@ -278,7 +280,7 @@ releases:
 			},
 			selectors: []string{"name=test2"},
 			templated: []exectest.Release{
-				{Name: "test2", Flags: []string(nil)},
+				{Name: "test2", Flags: []string{}},
 			},
 		})
 	})
@@ -292,8 +294,8 @@ releases:
 			},
 			selectors: []string{"name=test3"},
 			templated: []exectest.Release{
-				{Name: "test2", Flags: []string(nil)},
-				{Name: "test3", Flags: []string(nil)},
+				{Name: "test2", Flags: []string{}},
+				{Name: "test3", Flags: []string{}},
 			},
 		})
 	})
@@ -306,3 +308,190 @@ releases:
 		})
 	})
 }
+
+func TestTemplate_StrictParsing(t *testing.T) {
+	type testcase struct {
+		goccyGoYaml bool
+		ns          string
+		error       string
+	}
+
+	check := func(t *testing.T, tc testcase) {
+		t.Helper()
+
+		v := runtime.GoccyGoYaml
+		runtime.GoccyGoYaml = tc.goccyGoYaml
+		t.Cleanup(func() {
+			runtime.GoccyGoYaml = v
+		})
+
+		var helm = &exectest.Helm{
+			FailOnUnexpectedList: true,
+			FailOnUnexpectedDiff: true,
+			DiffMutex:            &sync.Mutex{},
+			ChartsMutex:          &sync.Mutex{},
+			ReleasesMutex:        &sync.Mutex{},
+			Helm3:                true,
+		}
+
+		_ = runWithLogCapture(t, "debug", func(t *testing.T, logger *zap.SugaredLogger) {
+			t.Helper()
+
+			valsRuntime, err := vals.New(vals.Options{CacheSize: 32})
+			if err != nil {
+				t.Errorf("unexpected error creating vals runtime: %v", err)
+			}
+
+			files := map[string]string{
+				"/path/to/helmfile.yaml": `
+releases:
+- name: app1
+  foobar: FOOBAR
+  chart: incubator/raw
+`,
+			}
+
+			app := appWithFs(&App{
+				OverrideHelmBinary:  DefaultHelmBinary,
+				fs:                  &ffs.FileSystem{Glob: filepath.Glob},
+				OverrideKubeContext: "default",
+				Env:                 "default",
+				Logger:              logger,
+				helms: map[helmKey]helmexec.Interface{
+					createHelmKey("helm", "default"): helm,
+				},
+				valsRuntime: valsRuntime,
+			}, files)
+
+			if tc.ns != "" {
+				app.Namespace = tc.ns
+			}
+
+			tmplErr := app.Template(applyConfig{
+				// if we check log output, concurrency must be 1. otherwise the test becomes non-deterministic.
+				concurrency: 1,
+				logger:      logger,
+			})
+
+			var gotErr string
+			if tmplErr != nil {
+				gotErr = tmplErr.Error()
+			}
+
+			if d := cmp.Diff(tc.error, gotErr); d != "" {
+				t.Fatalf("unexpected error: want (-), got (+): %s", d)
+			}
+		})
+	}
+
+	t.Run("fail due to unknown field with goccy/go-yaml", func(t *testing.T) {
+		check(t, testcase{
+			goccyGoYaml: true,
+			error: `in ./helmfile.yaml: failed to read helmfile.yaml: reading document at index 1: [4:3] unknown field "foobar"
+       2 | releases:
+       3 | - name: app1
+    >  4 |   foobar: FOOBAR
+             ^
+       5 |   chart: incubator/raw`,
+		})
+	})
+
+	t.Run("fail due to unknown field with gopkg.in/yaml.v2", func(t *testing.T) {
+		check(t, testcase{
+			goccyGoYaml: false,
+			error: `in ./helmfile.yaml: failed to read helmfile.yaml: reading document at index 1: yaml: unmarshal errors:
+  line 4: field foobar not found in type state.ReleaseSpec`,
+		})
+	})
+}
+
+func TestTemplate_CyclicInheritance(t *testing.T) {
+	type testcase struct {
+		ns    string
+		error string
+	}
+
+	check := func(t *testing.T, tc testcase) {
+		t.Helper()
+
+		var helm = &exectest.Helm{
+			FailOnUnexpectedList: true,
+			FailOnUnexpectedDiff: true,
+			DiffMutex:            &sync.Mutex{},
+			ChartsMutex:          &sync.Mutex{},
+			ReleasesMutex:        &sync.Mutex{},
+		}
+
+		_ = runWithLogCapture(t, "debug", func(t *testing.T, logger *zap.SugaredLogger) {
+			t.Helper()
+
+			valsRuntime, err := vals.New(vals.Options{CacheSize: 32})
+			if err != nil {
+				t.Errorf("unexpected error creating vals runtime: %v", err)
+			}
+
+			files := map[string]string{
+				"/path/to/helmfile.yaml": `
+templates:
+  a:
+    inherit:
+      template: b
+    values:
+    - a.yaml
+  b:
+    inherit:
+      template: c
+    values:
+    - b.yaml
+  c:
+    inherit:
+      template: a
+    values:
+    - c.yaml
+releases:
+- name: app1
+  inherit:
+    template: a
+  chart: incubator/raw
+`,
+			}
+
+			app := appWithFs(&App{
+				OverrideHelmBinary:  DefaultHelmBinary,
+				fs:                  &ffs.FileSystem{Glob: filepath.Glob},
+				OverrideKubeContext: "default",
+				Env:                 "default",
+				Logger:              logger,
+				helms: map[helmKey]helmexec.Interface{
+					createHelmKey("helm", "default"): helm,
+				},
+				valsRuntime: valsRuntime,
+			}, files)
+
+			if tc.ns != "" {
+				app.Namespace = tc.ns
+			}
+
+			tmplErr := app.Template(applyConfig{
+				// if we check log output, concurrency must be 1. otherwise the test becomes non-deterministic.
+				concurrency: 1,
+				logger:      logger,
+			})
+
+			var gotErr string
+			if tmplErr != nil {
+				gotErr = tmplErr.Error()
+			}
+
+			if d := cmp.Diff(tc.error, gotErr); d != "" {
+				t.Fatalf("unexpected error: want (-), got (+): %s", d)
+			}
+		})
+	}
+
+	t.Run("fail due to cyclic inheritance", func(t *testing.T) {
+		check(t, testcase{
+			error: `in ./helmfile.yaml: failed executing release templates in "helmfile.yaml": unable to load release "app1" with template: cyclic inheritance detected: a->b->c->a`,
+		})
+	})
+}
