@@ -19,6 +19,7 @@ type ConfigProvider interface {
 	loggingConfig
 }
 
+// TODO: Remove this function once Helmfile v0.x
 type DeprecatedChartsConfigProvider interface {
 	Values() []string
 
@@ -66,7 +67,9 @@ type ApplyConfigProvider interface {
 	Context() int
 	DiffOutput() string
 
+	// TODO: Remove this function once Helmfile v0.x
 	RetainValuesFiles() bool
+
 	Validate() bool
 	SkipCleanup() bool
 	SkipDiffOnInstall() bool
@@ -133,6 +136,7 @@ type DiffConfigProvider interface {
 	valuesControlMode
 }
 
+// TODO: Remove this function once Helmfile v0.x
 type DeleteConfigProvider interface {
 	Args() string
 
@@ -255,7 +259,8 @@ type InitConfigProvider interface {
 	Force() bool
 }
 
-// when enable reuse-values, reuse the last release's values and merge in any overrides values.
+// reset/reuse values helm cli flags handling for apply/sync/diff
 type valuesControlMode interface {
 	ReuseValues() bool
+	ResetValues() bool
 }
