@@ -2,9 +2,9 @@ package environment
 
 import (
 	"github.com/imdario/mergo"
-	"gopkg.in/yaml.v3"
 
 	"github.com/helmfile/helmfile/pkg/maputil"
+	"github.com/helmfile/helmfile/pkg/yaml"
 )
 
 type Environment struct {
@@ -15,8 +15,17 @@ type Environment struct {
 
 var EmptyEnvironment Environment
 
+// New return Environment with default name and values
+func New(name string) *Environment {
+	return &Environment{
+		Name:     name,
+		Values:   map[string]interface{}{},
+		Defaults: map[string]interface{}{},
+	}
+}
+
 func (e Environment) DeepCopy() Environment {
-	valuesBytes, err := maputil.YamlMarshal(e.Values)
+	valuesBytes, err := yaml.Marshal(e.Values)
 	if err != nil {
 		panic(err)
 	}
@@ -29,7 +38,7 @@ func (e Environment) DeepCopy() Environment {
 		panic(err)
 	}
 
-	defaultsBytes, err := maputil.YamlMarshal(e.Defaults)
+	defaultsBytes, err := yaml.Marshal(e.Defaults)
 	if err != nil {
 		panic(err)
 	}
