@@ -14,10 +14,10 @@ import (
 	"github.com/hashicorp/go-getter/helper/url"
 	"go.uber.org/multierr"
 	"go.uber.org/zap"
-	"gopkg.in/yaml.v3"
 
 	"github.com/helmfile/helmfile/pkg/envvar"
 	"github.com/helmfile/helmfile/pkg/filesystem"
+	"github.com/helmfile/helmfile/pkg/yaml"
 )
 
 var disableInsecureFeatures bool
@@ -27,6 +27,10 @@ func init() {
 }
 
 func CacheDir() string {
+	if h := os.Getenv(envvar.CacheHome); h != "" {
+		return h
+	}
+
 	dir, err := os.UserCacheDir()
 	if err != nil {
 		// fall back to relative path with hidden directory
