@@ -1,7 +1,6 @@
 package state
 
 import (
-	"bytes"
 	"errors"
 	"fmt"
 	"io"
@@ -9,20 +8,19 @@ import (
 	"github.com/imdario/mergo"
 	"github.com/variantdev/vals"
 	"go.uber.org/zap"
-	"gopkg.in/yaml.v3"
 
 	"github.com/helmfile/helmfile/pkg/environment"
 	"github.com/helmfile/helmfile/pkg/filesystem"
 	"github.com/helmfile/helmfile/pkg/helmexec"
 	"github.com/helmfile/helmfile/pkg/maputil"
 	"github.com/helmfile/helmfile/pkg/remote"
+	"github.com/helmfile/helmfile/pkg/yaml"
 )
 
 const (
 	DefaultHelmBinary = "helm"
 )
 
-// nolint: golint
 type StateLoadError struct {
 	msg   string
 	Cause error
@@ -90,9 +88,7 @@ func (c *StateCreator) Parse(content []byte, baseDir, file string) (*HelmState,
 
 	state.LockFile = c.lockFile
 
-	decoder := yaml.NewDecoder(bytes.NewReader(content))
-
-	decoder.KnownFields(c.Strict)
+	decode := yaml.NewDecoder(content, c.Strict)
 
 	i := 0
 	for {
@@ -100,7 +96,7 @@ func (c *StateCreator) Parse(content []byte, baseDir, file string) (*HelmState,
 
 		var intermediate HelmState
 
-		err := decoder.Decode(&intermediate)
+		err := decode(&intermediate)
 		if err == io.EOF {
 			break
 		} else if err != nil {
@@ -112,6 +108,7 @@ func (c *StateCreator) Parse(content []byte, baseDir, file string) (*HelmState,
 		}
 	}
 
+	// TODO: Remove this function once Helmfile v0.x
 	if len(state.DeprecatedReleases) > 0 {
 		if len(state.Releases) > 0 {
 			return nil, fmt.Errorf("failed to parse %s: you can't specify both `charts` and `releases` sections", file)
@@ -120,6 +117,7 @@ func (c *StateCreator) Parse(content []byte, baseDir, file string) (*HelmState,
 		state.DeprecatedReleases = []ReleaseSpec{}
 	}
 
+	// TODO: Remove this function once Helmfile v0.x
 	if state.DeprecatedContext != "" && state.HelmDefaults.KubeContext == "" {
 		state.HelmDefaults.KubeContext = state.DeprecatedContext
 	}
@@ -146,7 +144,7 @@ func (c *StateCreator) LoadEnvValues(target *HelmState, env string, ctxEnv *envi
 		return nil, &StateLoadError{fmt.Sprintf("failed to read %s", state.FilePath), err}
 	}
 
-	newDefaults, err := state.loadValuesEntries(nil, state.DefaultValues, c.remote, ctxEnv)
+	newDefaults, err := state.loadValuesEntries(nil, state.DefaultValues, c.remote, ctxEnv, env)
 	if err != nil {
 		return nil, err
 	}
@@ -221,7 +219,7 @@ func (c *StateCreator) loadEnvValues(st *HelmState, name string, failOnMissingEn
 	envSpec, ok := st.Environments[name]
 	if ok {
 		var err error
-		envVals, err = st.loadValuesEntries(envSpec.MissingFileHandler, envSpec.Values, c.remote, ctxEnv)
+		envVals, err = st.loadValuesEntries(envSpec.MissingFileHandler, envSpec.Values, c.remote, ctxEnv, name)
 		if err != nil {
 			return nil, err
 		}
@@ -300,18 +298,20 @@ func (c *StateCreator) scatterGatherEnvSecretFiles(st *HelmState, envSecretFiles
 				}
 
 				release := &ReleaseSpec{}
-				flags := st.appendConnectionFlags([]string{}, helm, release)
+				flags := st.appendConnectionFlags([]string{}, release)
 				decFile, err := helm.DecryptSecret(st.createHelmContext(release, 0), urlOrPath, flags...)
 				if err != nil {
 					results <- secretResult{secret.id, nil, err, secret.path}
 					continue
 				}
+
 				// nolint: staticcheck
 				defer func() {
 					if err := c.fs.DeleteFile(decFile); err != nil {
 						c.logger.Warnf("removing decrypted file %s: %w", decFile, err)
 					}
 				}()
+
 				bytes, err := c.fs.ReadFile(decFile)
 				if err != nil {
 					results <- secretResult{secret.id, nil, fmt.Errorf("failed to load environment secrets file \"%s\": %v", secret.path, err), secret.path}
@@ -363,13 +363,13 @@ func (c *StateCreator) scatterGatherEnvSecretFiles(st *HelmState, envSecretFiles
 	return nil
 }
 
-func (st *HelmState) loadValuesEntries(missingFileHandler *string, entries []interface{}, remote *remote.Remote, ctxEnv *environment.Environment) (map[string]interface{}, error) {
+func (st *HelmState) loadValuesEntries(missingFileHandler *string, entries []interface{}, remote *remote.Remote, ctxEnv *environment.Environment, envName string) (map[string]interface{}, error) {
 	var envVals map[string]interface{}
 
 	valuesEntries := append([]interface{}{}, entries...)
 	ld := NewEnvironmentValuesLoader(st.storage(), st.fs, st.logger, remote)
 	var err error
-	envVals, err = ld.LoadEnvironmentValues(missingFileHandler, valuesEntries, ctxEnv)
+	envVals, err = ld.LoadEnvironmentValues(missingFileHandler, valuesEntries, ctxEnv, envName)
 	if err != nil {
 		return nil, err
 	}
