@@ -8,18 +8,19 @@ import (
 	"os/exec"
 	"path/filepath"
 	"regexp"
-	"runtime"
+	goruntime "runtime"
+	"strconv"
 	"strings"
 	"testing"
 	"time"
 
 	"github.com/stretchr/testify/require"
 	"github.com/variantdev/chartify/helmtesting"
-	"gopkg.in/yaml.v3"
 
 	"github.com/helmfile/helmfile/pkg/app"
 	"github.com/helmfile/helmfile/pkg/envvar"
 	"github.com/helmfile/helmfile/pkg/helmexec"
+	"github.com/helmfile/helmfile/pkg/yaml"
 )
 
 var (
@@ -57,6 +58,18 @@ func (f fakeInit) Force() bool {
 }
 
 func TestHelmfileTemplateWithBuildCommand(t *testing.T) {
+	t.Run("with goccy/go-yaml", func(t *testing.T) {
+		testHelmfileTemplateWithBuildCommand(t, true)
+	})
+
+	t.Run("with gopkg.in/yaml.v2", func(t *testing.T) {
+		testHelmfileTemplateWithBuildCommand(t, false)
+	})
+}
+
+func testHelmfileTemplateWithBuildCommand(t *testing.T, goccyGoYaml bool) {
+	t.Setenv(envvar.GoccyGoYaml, strconv.FormatBool(goccyGoYaml))
+
 	localChartPortSets := make(map[int]struct{})
 
 	logger := helmexec.NewLogger(os.Stderr, "info")
@@ -69,10 +82,10 @@ func TestHelmfileTemplateWithBuildCommand(t *testing.T) {
 	err := helmfileInit.CheckHelmPlugins()
 	require.NoError(t, err)
 
-	_, filename, _, _ := runtime.Caller(0)
+	_, filename, _, _ := goruntime.Caller(0)
 	projectRoot := filepath.Join(filepath.Dir(filename), "..", "..", "..", "..")
 	helmfileBin := filepath.Join(projectRoot, "helmfile")
-	if runtime.GOOS == "windows" {
+	if goruntime.GOOS == "windows" {
 		helmfileBin = helmfileBin + ".exe"
 	}
 	testdataDir := "testdata/snapshot"
@@ -200,6 +213,15 @@ func TestHelmfileTemplateWithBuildCommand(t *testing.T) {
 				}
 			}
 
+			tmpDir := t.TempDir()
+			// HELM_CACHE_HOME contains downloaded chart archives
+			helmCacheHome := filepath.Join(tmpDir, "helm_cache")
+			// HELMFILE_CACHE_HOME contains remote charts and manifests downloaded by Helmfile using the go-getter integration
+			helmfileCacheHome := filepath.Join(tmpDir, "helmfile_cache")
+			// HELM_CONFIG_HOME contains the registry auth file (registry.json) and the index of all the repos added via helm-repo-add (repositories.yaml).
+			helmConfigHome := filepath.Join(tmpDir, "helm_config")
+			t.Logf("Using HELM_CACHE_HOME=%s, HELMFILE_CACHE_HOME=%s, HELM_CONFIG_HOME=%s", helmCacheHome, helmfileCacheHome, helmConfigHome)
+
 			inputFile := filepath.Join(testdataDir, name, "input.yaml")
 			outputFile := filepath.Join(testdataDir, name, "output.yaml")
 
@@ -214,6 +236,9 @@ func TestHelmfileTemplateWithBuildCommand(t *testing.T) {
 				cmd.Env,
 				envvar.TempDir+"=/tmp/helmfile",
 				envvar.DisableRunnerUniqueID+"=1",
+				"HELM_CACHE_HOME="+helmCacheHome,
+				"HELM_CONFIG_HOME="+helmConfigHome,
+				"HELMFILE_CACHE_HOME="+helmfileCacheHome,
 			)
 			got, err := cmd.CombinedOutput()
 			if err != nil {
@@ -231,6 +256,9 @@ func TestHelmfileTemplateWithBuildCommand(t *testing.T) {
 			gotStr = chartGitFullPathRegex.ReplaceAllString(gotStr, `chart=$$GoGetterPath`)
 			// Replace helm version with $HelmVersion
 			gotStr = helmShortVersionRegex.ReplaceAllString(gotStr, `$$HelmVersion`)
+			// Replace all occurrences of HELMFILE_CACHE_HOME with /home/runner/.cache/helmfile
+			// for stable test result
+			gotStr = strings.ReplaceAll(gotStr, helmfileCacheHome, "/home/runner/.cache/helmfile")
 
 			// OCI based helm charts are pulled and exported under temporary directory.
 			// We are not sure the exact name of the temporary directory generated by helmfile,
